<?php
/* Author: Alexandre Gorges */

$labels = array();
$labels['markreadfolder'] = 'Marcar todas como lidas';
$labels['collapseall'] = 'Recolher todas as pastas';
$labels['expandall'] = 'Expandir todas as pastas';
$labels['copyto'] = 'Copiar para...';

$messages = array();

?>