<?php
/* Author: Wouter Kevenaar */

$labels = array();
$labels['markreadfolder'] = 'Alles markeren als gelezen';
$labels['collapseall'] = 'Alle mappen inklappen';
$labels['expandall'] = 'Alle mappen uitklappen';
$labels['copyto'] = 'Kopiëren naar...';

$messages = array();

?>