<?php
/* Author: Daniel López */

$labels = array();
$labels['markreadfolder'] = 'Marcar todo como leído';
$labels['collapseall'] = 'Compactar todas las carpetas';
$labels['expandall'] = 'Expandir todas las carpetas';
$labels['copyto'] = 'Copiar a...';

$messages = array();

?>