<?php
/* Author: Mike Constabel */

$labels = array();
$labels['markreadfolder'] = 'Alle als gelesen markieren';
$labels['collapseall'] = 'Alle Unterordner einklappen';
$labels['expandall'] = 'Alle Unterordner ausklappen';
$labels['copyto'] = 'Kopieren nach ...';

$messages = array();

?>