<?php
/* Author: David Garabana Barro */

$labels = array();
$labels['markreadfolder'] = 'Marcar todas coma lidas';
$labels['collapseall'] = 'Pechar tódolos cartafoles';
$labels['expandall'] = 'Abrir tódolos cartafoles';
$labels['copyto'] = 'Copiar a...';

$messages = array();

?>