<?php
/* Author: Johannes Hessellund */

$labels = array();
$labels['markreadfolder'] = 'Markér alle som læst';
$labels['collapseall'] = 'Fold alle mapper sammen';
$labels['expandall'] = 'Udfold alle mapper';
$labels['copyto'] = 'Kopier til...';

$messages = array();

?>