<?php
/* Author: Daniel López */

$labels = array();
$labels['markreadfolder'] = 'Marca tot com a llegit';
$labels['collapseall'] = 'Compacta totes les carpetes';
$labels['expandall'] = 'Expandeix totes les carpetes';
$labels['copyto'] = 'Copia a ...';

$messages = array();

?>