/**
 * ContextMenu plugin styles
 */

.contextRow td,
#mailboxlist li.contextRow,
#directorylistbox li.contextRow
{
  background-color: #EEEEEE;
}

#mailboxlist li.selected,
#directorylistbox li.selected
{
  background-color: #929292;
}

#rcmContextMenu,
#rcmFolderMenu,
#rcmAddressMenu,
#rcmGroupMenu
{
  padding-top: 3px;
  min-width: 220px;
}

#rcmContextMenu li,
#rcmFolderMenu li,
#rcmAddressMenu li,
#rcmGroupMenu li
{
  margin: 0;
}

#rcmContextMenu li ul,
#rcmContextMenu li div,
#rcmFolderMenu li ul,
#rcmFolderMenu li div,
#rcmAddressMenu li ul,
#rcmAddressMenu li div,
#rcmGroupMenu li ul,
#rcmGroupMenu li div
{
  position: absolute;
  top: 0px;
  left: 0px;
  width: auto;
  display: none;
  background-color: #F9F9F9;
  border: 1px solid #CCC;
  padding: 1px;
  z-index: 901;
}

#rcmContextMenu li.conmentitle,
#rcmContextMenu li.submenu,
#rcmFolderMenu li.conmentitle,
#rcmFolderMenu li.submenu,
#rcmAddressMenu li.conmentitle,
#rcmAddressMenu li.submenu,
#rcmGroupMenu li.conmentitle,
#rcmGroupMenu li.submenu
{
  padding: 2px 8px 3px 27px;
  cursor: default;
}

#rcmContextMenu li.sublink,
#rcmFolderMenu li.sublink,
#rcmAddressMenu li.sublink,
#rcmGroupMenu li.sublink
{
  padding: 0;
}

#rcmContextMenu li.submenu,
#rcmFolderMenu li.submenu,
#rcmAddressMenu li.submenu,
#rcmGroupMenu li.submenu
{
  position: relative;
  cursor: pointer;
  background: url(contexticons.png) no-repeat right 0;
  padding-right: 15px;
}

#rcmContextMenu li.replyacts,
#rcmContextMenu li.forwardacts,
#rcmAddressMenu li.exportacts
{
 padding: 0 8px 0 0;
}

#rcmContextMenu li.markmessage a,
#rcmAddressMenu li.contactgroup a
{
  text-indent: 8px;
}

#rcmContextMenu li.submenu:hover,
#rcmContextMenu li.sublink:hover a.mainlink,
#rcmFolderMenu li.submenu:hover,
#rcmFolderMenu li.sublink:hover a.mainlink,
#rcmAddressMenu li.submenu:hover,
#rcmAddressMenu li.sublink:hover a.mainlink,
#rcmGroupMenu li.submenu:hover,
#rcmGroupMenu li.sublink:hover a.mainlink
{
  color: #fff;
  background-color: #CC0000;
}

#rcmContextMenu li a,
#rcmFolderMenu li a,
#rcmAddressMenu li a,
#rcmGroupMenu li a
{
  background: url(contexticons.png) no-repeat 7px 20px;
}

#rcmContextMenu li a.active:hover,
#rcmFolderMenu li a.active:hover,
#rcmAddressMenu li a.active:hover,
#rcmGroupMenu li a.active:hover
{
  color: #fff;
  background-color: #CC0000;
}

#rcmContextMenu a.disabled,
#rcmFolderMenu a.disabled,
#rcmAddressMenu a.disabled,
#rcmGroupMenu a.disabled
{
  color: #AAA;
  cursor: default;
}

#rcmContextMenu a.disabled:hover,
#rcmFolderMenu a.disabled:hover,
#rcmAddressMenu a.disabled:hover,
#rcmGroupMenu a.disabled:hover
{
  color: #AAA;
  background-color: transparent
}

#rcmContextMenu .read a
{
  background-position: 7px -85px;
}

#rcmFolderMenu .readfolder a
{
  background-position: 7px -85px;
}

#rcmContextMenu .unread a
{
  background-position: 7px -136px;
}
#rcmContextMenu .flagged a
{
  background-position: 7px -170px;
}

#rcmContextMenu .unflagged a
{
  background-position: 7px -153px;
}

#rcmContextMenu .reply a, #rcmContextMenu .replyall a, #rcmContextMenu .replylist a
{
  background-position: 7px -119px;
}

#rcmContextMenu .forwardinline a, #rcmContextMenu .forwardattachment a
{
  background-position: 7px -102px;
}

#rcmContextMenu .delete a,
#rcmAddressMenu .deletecontact a
{
  background-position: 7px -187px;
}

#rcmFolderMenu .expunge a
{
  background-position: 7px -255px;
}

#rcmFolderMenu .purge a
{
  background-position: 7px -272px;
}

#rcmFolderMenu .collapseall a
{
  background-position: 7px -204px;
}

#rcmFolderMenu .expandall a
{
  background-position: 7px -220px;
}

#rcmContextMenu ul.moreacts li a
{
  background: url(messageactions.png) no-repeat 5px 20px;
}

#rcmContextMenu ul.moreacts li.print a
{
  background-position: 5px 1px;
}

#rcmContextMenu ul.moreacts li.source a
{
  background-position: 5px -35px;
}

#rcmContextMenu ul.moreacts li.save a
{
  background-position: 5px -17px;
}

#rcmContextMenu ul.moreacts li.open a
{
  background-position: 5px -53px;
}

#rcmFolderMenu .openfolder a
{
  background: url(messageactions.png) no-repeat 6px -53px;
}

#rcmContextMenu ul.moreacts li.edit a
{
  background-position: 5px -71px;
}

#rcmAddressMenu .editcontact a
{
   background: url(messageactions.png) no-repeat 6px -71px;
}

#rcmAddressMenu .composeto a
{
  background-position: 8px -238px;
}

#rcmContextMenu ul.folders li a,
#rcmAddressMenu ul.folders li a
{
  background: url(folders.png) 5px 1px no-repeat;
}

#rcmContextMenu ul.folders li.inbox a
{
  background-position: 5px -17px;
}

#rcmContextMenu ul.folders li.drafts a
{
  background-position: 5px -36px;
}

#rcmContextMenu ul.folders li.sent a
{
  background-position: 5px -54px;
}

#rcmContextMenu ul.folders li.junk a
{
  background-position: 5px -73px;
}

#rcmContextMenu ul.folders li.trash a
{
  background-position: 5px -90px;
}

#rcmAddressMenu ul.folders li.addressbook a
{
  background-position: 5px -108px;
}

#rcmAddressMenu ul.folders li.contactgroup a
{
  background-position: 5px -144px;
}

#rcmContextMenu div.popupmenu,
#rcmFolderMenu div.popupmenu,
#rcmAddressMenu div.popupmenu
{
  height: 129px;
  padding: 0;
}

#rcmContextMenu ul.scrollable,
#rcmFolderMenu ul.scrollable,
#rcmAddressMenu ul.scrollable
{
  top: 15px;
  height: 100px;
  overflow: hidden;
  border-top: 0;
  border-bottom: 0;
  margin: 0;
}

#rcmContextMenu li div,
#rcmFolderMenu li div,
#rcmAddressMenu li div
{
  height: 12px;
  overflow: hidden;
  background: url(contexticons.png) #F9F9F9 no-repeat center 20px;
}

#rcmContextMenu li div.scroll_up_act,
#rcmFolderMenu li div.scroll_up_act,
#rcmAddressMenu li div.scroll_up_act
{
  background-position: center -17px;
  border-bottom: 0;
}

#rcmContextMenu li div.scroll_up_pas,
#rcmFolderMenu li div.scroll_up_pas,
#rcmAddressMenu li div.scroll_up_pas
{
  background-position: center -34px;
  border-bottom: 0;
  cursor: default;
}

#rcmContextMenu li div.scroll_down_act,
#rcmFolderMenu li div.scroll_down_act,
#rcmAddressMenu li div.scroll_down_act
{
  top: 117px;
  background-position: center -51px;
  border-top: 0;
}

#rcmContextMenu li div.scroll_down_pas,
#rcmFolderMenu li div.scroll_down_pas,
#rcmAddressMenu li div.scroll_down_pas
{
  top: 117px;
  background-position: center -68px;
  border-top: 0;
  cursor: default;
}