<?php
/* Author: Jonas Nasholm */

$labels = array();
$labels['markreadfolder'] = 'Märk allt som läst';
$labels['collapseall'] = 'Dölj alla kataloger';
$labels['expandall'] = 'Visa alla kataloger';
$labels['copyto'] = 'Kopiera till...';

$messages = array();

?>