<?php
/* Author: Massimiliano Adamo */

$labels = array();
$labels['markreadfolder'] = 'Marca tutto come letto';
$labels['collapseall'] = 'Compatta tutte le cartelle';
$labels['expandall'] = 'Espandi tutte le cartelle';
$labels['copyto'] = 'Copia su...';

$messages = array();

?>