<?php
/* Author: */

$labels = array();
$labels['markreadfolder'] = 'Marquer tout comme lu';
$labels['collapseall'] = 'Reduire les dossiers';
$labels['expandall'] = 'Developper les dossiers';
$labels['copyto'] = 'Copier vers...';

$messages = array();

?>