<?php
/* Author: thomasysliu */

$labels = array();
$labels['markreadfolder'] = '標示為已讀取';
$labels['collapseall'] = '全部收起';
$labels['expandall'] = '全部展開';
$labels['copyto'] = '複製到...';

$messages = array();

?>