<?php
/* Author: Németh János */

$labels = array();
$labels['markreadfolder'] = 'Összes megjelölése olvasottként';
$labels['collapseall'] = 'Összes összecsukása';
$labels['expandall'] = 'Összes kibontása';
$labels['copyto'] = 'Másolás...';

$messages = array();

?>