<?php
/* Author: Sergey Basov */

$labels = array();
$labels['markreadfolder'] = 'Отметить все как прочитанные';
$labels['collapseall'] = 'Свернуть все папки';
$labels['expandall'] = 'Развернуть все папки';
$labels['copyto'] = 'Копировать в...';

$messages = array();

?>