<?php
/* Author: Philip Weir */

$labels = array();
$labels['markreadfolder'] = 'Mark all as read';
$labels['collapseall'] = 'Collapse all folders';
$labels['expandall'] = 'Expand all folders';
$labels['copyto'] = 'Copy to...';

$messages = array();

?>