<?php
/* Author: Sergey Basov */

$labels = array();
$labels['markreadfolder'] = 'Відмітити все як прочитане';
$labels['collapseall'] = 'Згорнути усі папки';
$labels['expandall'] = 'Розгорнути усі папки';
$labels['copyto'] = 'Копіювати до...';

$messages = array();

?>