<?php
/* Author: Martin Frajdl */

$labels = array();
$labels['markreadfolder'] = 'Oznacit vše jako přečtené';
$labels['collapseall'] = 'Sbalit všechny složky';
$labels['expandall'] = 'Rozbalit všechny složky';
$labels['copyto'] = 'Kopírovat do...';

$messages = array();

?>