<?php
/* Author: Mustafa Icer */

$labels = array();
$labels['markreadfolder'] = 'Tüm mesajları okunumuş olarak işaretle';
$labels['collapseall'] = 'Tüm alt klasörleri kapat';
$labels['expandall'] = 'Tüm alt klasörleri aç';
$labels['copyto'] = '... kopyala';

$messages = array();

?>