<?php
/* Author: Michał Jałocha */

$labels = array();
$labels['markreadfolder'] = 'Oznacz wszystkie jako przeczytane';
$labels['collapseall'] = 'Zwiń wszystkie foldery';
$labels['expandall'] = 'Rozwiń wszystkie foldery';
$labels['copyto'] = 'Kopiuj do...';

$messages = array();

?>