<?php
/* Author: Ovidiu Bica */

$labels = array();
$labels['markreadfolder'] = 'Marchează mesajele ca citite';
$labels['collapseall'] = 'Ascunde toate folderele';
$labels['expandall'] = 'Afişează toate folderele';
$labels['copyto'] = 'Copiaza in';

$messages = array();

?>